import { CommonModule } from '@angular/common';
import { Component } from '@angular/core';
import { FormsModule } from '@angular/forms';
import { ResourcePipe } from '../resource.pipe';
import { NzInputModule } from 'ng-zorro-antd/input';
import { NzButtonModule } from 'ng-zorro-antd/button';

@Component({
  selector: 'app-login',
  templateUrl: './login.component.html',
  styleUrls: ['./login.component.scss'],
  standalone: true,
  imports: [
    CommonModule,
    FormsModule, // 导入FormsModule以支持双向数据绑定
    ResourcePipe,
    NzInputModule,
    NzButtonModule
  ],
})
export class LoginComponent {
  username: string = '';
  password: string = '';
  captcha: string = '';
  captchaAnswer: string = '';
  captchaImage: string = '';

  constructor() {
    this.refreshCaptcha();
  }

  refreshCaptcha(): void {
    // 这里可以调用后端API获取新的验证码图片URL
    this.captchaImage = this.genRandomStringImage(4);
  }
  genRandomStringImage(length: number): string {
  const characters = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
  let result = '';
  for (let i = 0; i < length; i++) {
    const randomIndex = Math.floor(Math.random() * characters.length);
    result += characters.charAt(randomIndex);
  }

  this.captchaAnswer = result;
  // 创建 canvas 元素
  const canvas = document.createElement('canvas');
  canvas.width = 100;
  canvas.height = 30;
  const context = canvas.getContext('2d');
  if (!context) {
    return '';
  }

  // 设置背景颜色
  context.fillStyle = '#000';
  context.fillRect(0, 0, canvas.width, canvas.height);

  // 添加干扰线
  context.strokeStyle = '#fff';
  context.lineWidth = 1;
  for (let i = 0; i < 5; i++) {
    context.beginPath();
    context.moveTo(Math.random() * canvas.width, Math.random() * canvas.height);
    context.lineTo(Math.random() * canvas.width, Math.random() * canvas.height);
    context.stroke();
  }

  // 设置文字颜色和字体
  context.fillStyle = '#fff';
  context.font = '20px Arial';

  // 添加文字扭曲
  context.save();
  context.translate(10, 20);
  context.rotate((Math.random() - 0.5) * 0.1); // 轻微旋转
  context.fillText(result, 0, 0);
  context.restore();

  // 将 canvas 内容转换为 base64 URL
  const base64Url = canvas.toDataURL('image/png');
  return base64Url;
}

  onSubmit(): void {
    // 处理登录逻辑
    const data = {
      username: this.username,
      password: this.encryptPassword(this.password)
    }
    // post to /api/login
    fetch('/api/login', {
      method: 'POST',
      headers: {
        'Content-Type': 'application/json'
      },
      body: JSON.stringify(data)
    })
    .then(response => response.json())
    .then(data => {
      if (data.code === 0) {
        // 登录成功，跳转到首页
        console.log('登录成功');
      } else {
        // 登录失败，显示错误信息
      }

    })
  }

  captchaIsCorrect(): boolean {
    return this.captcha.toLowerCase() === this.captchaAnswer.toLowerCase();
  }

  encryptPassword(password: string): string {
    // 这里可以添加密码加密逻辑
    const plaintext = `${password}${Date.now()}`
    let ciphertext = '';
    for (let i = 0; i < plaintext.length; i++) {
        const d = plaintext.charCodeAt(i)^0xFF;
        ciphertext += d.toString(16);
    }
    return ciphertext;
    // return password;
  }
}